@@ -42,6 +42,7 @@ SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 #include <QMenu>
 #include <QMimeData>
 #include <QMimeDatabase>
+#include <QPainter>
 #include <QProcess>
 #include <QResizeEvent>
 #include <QScrollArea>
@@ -70,7 +71,7 @@ void ElidedLinkLabel::updateText(int width)
     if (m_link.isEmpty()) {
         setText(fontMetrics().elidedText(m_text, Qt::ElideLeft, width));
     } else {
-        setText(QString("<a href=\"%1\">%2</a>").arg(m_link, fontMetrics().elidedText(m_text, Qt::ElideLeft, width)));
+        setText(QStringLiteral("<a href=\"%1\">%2</a>").arg(m_link, fontMetrics().elidedText(m_text, Qt::ElideLeft, width)));
     }
 }
 
@@ -104,11 +105,7 @@ AnalysisTree::AnalysisTree(QWidget *parent)
 }
 
 // virtual
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 QMimeData *AnalysisTree::mimeData(const QList<QTreeWidgetItem *> &list) const
-#else
-QMimeData *AnalysisTree::mimeData(const QList<QTreeWidgetItem *> list) const
-#endif
 {
     QString mimeData;
     for (QTreeWidgetItem *item : list) {
@@ -165,18 +162,10 @@ public:
         }
         if (decode) {
             KFileMetaData::PropertyInfo info(property);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            if (info.valueType() == QVariant::DateTime) {
-#else
             if (info.valueType() == QMetaType::Type::QDateTime) {
-#endif
                 QLocale locale;
                 new QTreeWidgetItem(m_tree, {info.displayName(), locale.toDateTime(value.toString(), QLocale::ShortFormat).toString()});
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            } else if (info.valueType() == QVariant::Int) {
-#else
-                } else if (info.valueType() == QMetaType::Type::Int) {
-#endif
+            } else if (info.valueType() == QMetaType::Type::Int) {
                 int val = value.toInt();
                 if (property == KFileMetaData::Property::BitRate) {
                     // Adjust unit for bitrate
@@ -185,11 +174,7 @@ public:
                 } else {
                     new QTreeWidgetItem(m_tree, QStringList{info.displayName(), QString::number(val)});
                 }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            } else if (info.valueType() == QVariant::Double) {
-#else
-                } else if (info.valueType() == QMetaType::Type::Double) {
-#endif
+            } else if (info.valueType() == QMetaType::Type::Double) {
                 new QTreeWidgetItem(m_tree, QStringList{info.displayName(), QString::number(value.toDouble())});
             } else {
                 new QTreeWidgetItem(m_tree, QStringList{info.displayName(), value.toString()});
@@ -226,18 +211,19 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
     } else {
         m_clipLabel->setLabelText(controller->clipUrl(), controller->clipUrl());
     }
-    connect(m_clipLabel, &QLabel::linkActivated, [](const QString &link) { KIO::highlightInFileManager({QUrl::fromLocalFile(link)}); });
+    connect(m_clipLabel, &QLabel::linkActivated, [](const QString &link) { pCore->highlightFileInExplorer({QUrl::fromLocalFile(link)}); });
     lay->addWidget(m_clipLabel);
-    lay->addWidget(&m_warningMessage);
-    m_warningMessage.setCloseButtonVisible(false);
-    m_warningMessage.setWordWrap(true);
-    m_warningMessage.hide();
+    m_warningMessage = new KMessageWidget(this);
+    lay->addWidget(m_warningMessage);
+    m_warningMessage->setCloseButtonVisible(false);
+    m_warningMessage->setWordWrap(true);
+    m_warningMessage->hide();
     m_tabWidget = new QTabWidget(this);
-    lay->addWidget(m_tabWidget);
-    setLayout(lay);
     m_tabWidget->setDocumentMode(true);
     m_tabWidget->setTabPosition(QTabWidget::East);
     m_tabWidget->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
+    lay->addWidget(m_tabWidget);
+    setLayout(lay);
     auto *forcePage = new QScrollArea(this);
     auto *forceAudioPage = new QScrollArea(this);
     m_propertiesPage = new QWidget(this);
@@ -273,7 +259,7 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
     aBox->addWidget(new QLabel(i18n("Analysis data")));
     aBox->addWidget(m_analysisTree);
     auto *bar2 = new QToolBar;
-    bar2->addAction(QIcon::fromTheme(QStringLiteral("trash-empty")), i18n("Delete analysis"), this, SLOT(slotDeleteAnalysis()));
+    bar2->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Delete analysis"), this, SLOT(slotDeleteAnalysis()));
     bar2->setWhatsThis(xi18nc("@info:whatsthis", "Deletes the data set(s)."));
     bar2->addAction(QIcon::fromTheme(QStringLiteral("document-save-as")), i18n("Export analysis…"), this, SLOT(slotSaveAnalysis()));
     bar2->setWhatsThis(xi18nc("@info:whatsthis", "Opens a file dialog window to export/save the analysis data."));
@@ -321,7 +307,11 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
         hlay->addWidget(timePos);
         fpBox->addLayout(hlay);
         connect(box, &QAbstractButton::toggled, timePos, &QWidget::setEnabled);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+        connect(box, &QCheckBox::checkStateChanged, this, &ClipPropertiesController::slotEnableForce);
+#else
         connect(box, &QCheckBox::stateChanged, this, &ClipPropertiesController::slotEnableForce);
+#endif
         connect(timePos, &TimecodeDisplay::timeCodeEditingFinished, this, &ClipPropertiesController::slotDurationChanged);
         connect(this, SIGNAL(modified(int)), timePos, SLOT(setValue(int)));
 
@@ -331,7 +321,11 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
             m_originalProperties.insert(QStringLiteral("disable_exif"), QString::number(autorotate));
             hlay = new QHBoxLayout;
             box = new QCheckBox(i18n("Disable autorotate"), this);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+            connect(box, &QCheckBox::checkStateChanged, this, &ClipPropertiesController::slotEnableForce);
+#else
             connect(box, &QCheckBox::stateChanged, this, &ClipPropertiesController::slotEnableForce);
+#endif
             box->setObjectName(QStringLiteral("disable_exif"));
             box->setChecked(autorotate == 1);
             hlay->addWidget(box);
@@ -368,20 +362,26 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
 
         fpBox->addLayout(colorLay);
         connect(choosecolor, &ChooseColorWidget::modified, this, &ClipPropertiesController::slotColorModified);
-        connect(this, static_cast<void (ClipPropertiesController::*)(const QColor &)>(&ClipPropertiesController::modified), choosecolor,
-                &ChooseColorWidget::slotColorModified);
+        connect(this, &ClipPropertiesController::colorModified, choosecolor, &ChooseColorWidget::slotColorModified);
     }
     if (m_type == ClipType::AV || m_type == ClipType::Video || m_type == ClipType::Image) {
         // Aspect ratio
-        int force_ar_num = m_properties->get_int("force_aspect_num");
-        int force_ar_den = m_properties->get_int("force_aspect_den");
-        m_originalProperties.insert(QStringLiteral("force_aspect_den"), (force_ar_den == 0) ? QString() : QString::number(force_ar_den));
-        m_originalProperties.insert(QStringLiteral("force_aspect_num"), (force_ar_num == 0) ? QString() : QString::number(force_ar_num));
+        double ratio = 0.;
+        if (m_properties->property_exists("force_aspect_ratio")) {
+            ratio = m_properties->get_double("force_aspect_ratio");
+            m_originalProperties.insert(QStringLiteral("force_aspect_den"), QString::number(ratio));
+        } else {
+            m_originalProperties.insert(QStringLiteral("force_aspect_den"), QString());
+        }
         auto *hlay = new QHBoxLayout;
         QCheckBox *box = new QCheckBox(i18n("Aspect ratio:"), this);
         box->setObjectName(QStringLiteral("force_ar"));
         fpBox->addWidget(box);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+        connect(box, &QCheckBox::checkStateChanged, this, &ClipPropertiesController::slotEnableForce);
+#else
         connect(box, &QCheckBox::stateChanged, this, &ClipPropertiesController::slotEnableForce);
+#endif
         auto *spin1 = new QSpinBox(this);
         spin1->setMaximum(8000);
         spin1->setObjectName(QStringLiteral("force_aspect_num_value"));
@@ -393,7 +393,7 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
         spin2->setMaximum(8000);
         spin2->setObjectName(QStringLiteral("force_aspect_den_value"));
         hlay->addWidget(spin2);
-        if (force_ar_num == 0) {
+        if (ratio == 0.) {
             // use current ratio
             int num = m_properties->get_int("meta.media.sample_aspect_num");
             int den = m_properties->get_int("meta.media.sample_aspect_den");
@@ -409,8 +409,16 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
             box->setChecked(true);
             spin1->setEnabled(true);
             spin2->setEnabled(true);
-            spin1->setValue(force_ar_num);
-            spin2->setValue(force_ar_den);
+
+            int ratio_num = qRound(ratio * 1000);
+            int ratio_den = 1000;
+            int num = ProfilesDialog::gcd(ratio_num, ratio_den);
+            if (num > 0) {
+                ratio_num /= num;
+                ratio_den /= num;
+            }
+            spin1->setValue(ratio_num);
+            spin2->setValue(ratio_den);
         }
         connect(spin2, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &ClipPropertiesController::slotAspectValueChanged);
         connect(spin1, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &ClipPropertiesController::slotAspectValueChanged);
@@ -444,7 +452,7 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
                     // Probable an image proxy
                     lab->setText(i18n("Image"));
                 } else {
-                    lab->setText(m_properties->get(QString("meta.media.%1.codec.name").arg(m_properties->get_int("video_index")).toUtf8().constData()));
+                    lab->setText(m_properties->get(QStringLiteral("meta.media.%1.codec.name").arg(m_properties->get_int("video_index")).toUtf8().constData()));
                 }
             } else {
                 pbox->setCheckState(Qt::PartiallyChecked);
@@ -453,7 +461,11 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
             pbox->setCheckState(Qt::Unchecked);
         }
         pbox->setEnabled(pCore->projectManager()->current()->useProxy());
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+        connect(pbox, &QCheckBox::checkStateChanged, this, [this, pbox](Qt::CheckState state) {
+#else
         connect(pbox, &QCheckBox::stateChanged, this, [this, pbox](int state) {
+#endif
             Q_EMIT requestProxy(state == Qt::PartiallyChecked);
             if (state == Qt::Checked) {
                 QSignalBlocker bk(pbox);
@@ -467,8 +479,9 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
             pbox->setCheckState(hasProxyClip ? Qt::Checked : Qt::Unchecked);
             bg->setEnabled(pbox->isChecked());
             bg->setToolTip(pxy);
-            lab->setText(hasProxyClip ? m_properties->get(QString("meta.media.%1.codec.name").arg(m_properties->get_int("video_index")).toUtf8().constData())
-                                      : QString());
+            lab->setText(hasProxyClip
+                             ? m_properties->get(QStringLiteral("meta.media.%1.codec.name").arg(m_properties->get_int("video_index")).toUtf8().constData())
+                             : QString());
         });
         hlay->addWidget(pbox);
         bg->setEnabled(pbox->checkState() == Qt::Checked);
@@ -494,7 +507,7 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
         QAction *ac = new QAction(QIcon::fromTheme(QStringLiteral("document-open")), i18n("Open folder…"), this);
         connect(ac, &QAction::triggered, this, [this]() {
             QString pxy = m_properties->get("kdenlive:proxy");
-            KIO::highlightInFileManager({QUrl::fromLocalFile(pxy)});
+            pCore->highlightFileInExplorer({QUrl::fromLocalFile(pxy)});
         });
         pMenu->addAction(ac);
         ac = new QAction(QIcon::fromTheme(QStringLiteral("media-playback-start")), i18n("Play proxy clip"), this);
@@ -522,7 +535,11 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
         auto *hlay = new QHBoxLayout;
         QCheckBox *box = new QCheckBox(i18n("Frame rate:"), this);
         box->setObjectName(QStringLiteral("force_fps"));
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+        connect(box, &QCheckBox::checkStateChanged, this, &ClipPropertiesController::slotEnableForce);
+#else
         connect(box, &QCheckBox::stateChanged, this, &ClipPropertiesController::slotEnableForce);
+#endif
         auto *spin = new QDoubleSpinBox(this);
         spin->setMaximum(1000);
         connect(spin, SIGNAL(valueChanged(double)), this, SLOT(slotValueChanged(double)));
@@ -545,7 +562,11 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
         m_originalProperties.insert(QStringLiteral("force_progressive"), force_prog.isEmpty() ? QStringLiteral("-") : force_prog);
         hlay = new QHBoxLayout;
         box = new QCheckBox(i18n("Scanning:"), this);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+        connect(box, &QCheckBox::checkStateChanged, this, &ClipPropertiesController::slotEnableForce);
+#else
         connect(box, &QCheckBox::stateChanged, this, &ClipPropertiesController::slotEnableForce);
+#endif
         box->setObjectName(QStringLiteral("force_progressive"));
         auto *combo = new QComboBox(this);
         combo->addItem(i18n("Interlaced"), 0);
@@ -567,7 +588,11 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
         m_originalProperties.insert(QStringLiteral("force_tff"), force_tff.isEmpty() ? QStringLiteral("-") : force_tff);
         hlay = new QHBoxLayout;
         box = new QCheckBox(i18n("Field order:"), this);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+        connect(box, &QCheckBox::checkStateChanged, this, &ClipPropertiesController::slotEnableForce);
+#else
         connect(box, &QCheckBox::stateChanged, this, &ClipPropertiesController::slotEnableForce);
+#endif
         box->setObjectName(QStringLiteral("force_tff"));
         combo = new QComboBox(this);
         combo->addItem(i18n("Bottom First"), 0);
@@ -592,9 +617,13 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
         box->setObjectName(QStringLiteral("autorotate"));
         box->setChecked(autorotate == QLatin1String("0"));
         int vix = m_sourceProperties->get_int("video_index");
-        const QString query = QString("meta.media.%1.codec.rotate").arg(vix);
+        const QString query = QStringLiteral("meta.media.%1.codec.rotate").arg(vix);
         int angle = m_sourceProperties->get_int(query.toUtf8().constData());
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+        connect(box, &QCheckBox::checkStateChanged, this, &ClipPropertiesController::slotEnableForce);
+#else
         connect(box, &QCheckBox::stateChanged, this, &ClipPropertiesController::slotEnableForce);
+#endif
 
         // Rotate
         int rotate = 0;
@@ -620,7 +649,11 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
         }
         // Disable force rotate when autorotate is disabled
         combo->setEnabled(!box->isChecked());
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+        connect(box, &QCheckBox::checkStateChanged, this, [combo](Qt::CheckState state) { combo->setEnabled(state != Qt::Unchecked); });
+#else
         connect(box, &QCheckBox::stateChanged, this, [combo](int state) { combo->setEnabled(state != Qt::Unchecked); });
+#endif
         connect(combo, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ClipPropertiesController::slotComboValueChanged);
         hlay->addWidget(box);
         hlay->addWidget(combo);
@@ -643,7 +676,7 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
             hlay->addWidget(new QLabel(i18n("Video stream")));
             auto *videoStream = new QComboBox(this);
             int ix = 1;
-            for (int stream : qAsConst(m_videoStreams)) {
+            for (int stream : std::as_const(m_videoStreams)) {
                 videoStream->addItem(i18n("Video stream %1", ix), stream);
                 ix++;
             }
@@ -684,14 +717,14 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
             QString vix = m_sourceProperties->get("audio_index");
             m_originalProperties.insert(QStringLiteral("audio_index"), vix);
             QStringList streamString;
-            for (int streamIx : qAsConst(enabledStreams)) {
+            for (int streamIx : std::as_const(enabledStreams)) {
                 streamString << QString::number(streamIx);
             }
             m_originalProperties.insert(QStringLiteral("kdenlive:active_streams"), streamString.join(QLatin1Char(';')));
             hlay = new QHBoxLayout;
 
             KDualAction *ac = new KDualAction(i18n("Disable audio"), i18n("Enable audio"), this);
-            ac->setInactiveIcon(QIcon::fromTheme(QStringLiteral("kdenlive-show-audio")));
+            ac->setInactiveIcon(QIcon::fromTheme(QStringLiteral("audio-volume-high")));
             ac->setActiveIcon(QIcon::fromTheme(QStringLiteral("audio-off")));
             auto *tbv = new QToolButton(this);
             tbv->setToolButtonStyle(Qt::ToolButtonIconOnly);
@@ -744,7 +777,7 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
                     m_copyChannel2->setChecked(effects.contains(QStringLiteral("channelcopy from=1 to=0")));
                     m_normalize->setChecked(effects.contains(QStringLiteral("dynamic_loudness")));
                     int gain = 0;
-                    for (const QString &st : qAsConst(effects)) {
+                    for (const QString &st : std::as_const(effects)) {
                         if (st.startsWith(QLatin1String("volume "))) {
                             QSignalBlocker bk3(m_gain);
                             gain = st.section(QLatin1Char('='), 1).toInt();
@@ -797,8 +830,8 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
                     // Rename event
                     QString txt = item->text();
                     int row = m_audioStreamsView->row(item) + 1;
-                    if (!txt.startsWith(QString("%1|").arg(row))) {
-                        txt.prepend(QString("%1|").arg(row));
+                    if (!txt.startsWith(QStringLiteral("%1|").arg(row))) {
+                        txt.prepend(QStringLiteral("%1|").arg(row));
                     }
                     m_controller->renameAudioStream(streamId, txt);
                     QSignalBlocker bk(m_audioStreamsView);
@@ -832,7 +865,11 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
             auto *vbox = new QVBoxLayout;
             // Normalize
             m_normalize = new QCheckBox(i18n("Normalize"), this);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+            connect(m_normalize, &QCheckBox::checkStateChanged, this, [this](Qt::CheckState state) {
+#else
             connect(m_normalize, &QCheckBox::stateChanged, this, [this](int state) {
+#endif
                 if (m_activeAudioStreams == -1) {
                     // No stream selected, abort
                     return;
@@ -850,7 +887,11 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
 
             // Swap channels
             m_swapChannels = new QCheckBox(i18n("Swap channels"), this);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+            connect(m_swapChannels, &QCheckBox::checkStateChanged, this, [this](Qt::CheckState state) {
+#else
             connect(m_swapChannels, &QCheckBox::stateChanged, this, [this](int state) {
+#endif
                 if (m_activeAudioStreams == -1) {
                     // No stream selected, abort
                     return;
@@ -911,7 +952,7 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
                     // Remove effect
                     m_controller->requestRemoveStreamEffect(m_activeAudioStreams, QStringLiteral("volume"));
                 } else {
-                    m_controller->requestAddStreamEffect(m_activeAudioStreams, QString("volume level=%1").arg(value));
+                    m_controller->requestAddStreamEffect(m_activeAudioStreams, QStringLiteral("volume level=%1").arg(value));
                 }
                 updateStreamIcon(m_audioStreamsView->currentRow(), m_activeAudioStreams);
             });
@@ -948,7 +989,11 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
         hlay = new QHBoxLayout;
         box = new QCheckBox(i18n("Color space:"), this);
         box->setObjectName(QStringLiteral("force_colorspace"));
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+        connect(box, &QCheckBox::checkStateChanged, this, &ClipPropertiesController::slotEnableForce);
+#else
         connect(box, &QCheckBox::stateChanged, this, &ClipPropertiesController::slotEnableForce);
+#endif
         combo = new QComboBox(this);
         combo->setObjectName(QStringLiteral("force_colorspace_value"));
         combo->addItem(ProfileRepository::getColorspaceDescription(240), 240);
@@ -981,7 +1026,11 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
         hlay = new QHBoxLayout;
         box = new QCheckBox(i18n("Color range:"), this);
         box->setObjectName(QStringLiteral("force_color_range"));
+#if QT_VERSION >= QT_VERSION_CHECK(6, 7, 0)
+        connect(box, &QCheckBox::checkStateChanged, this, &ClipPropertiesController::slotEnableForce);
+#else
         connect(box, &QCheckBox::stateChanged, this, &ClipPropertiesController::slotEnableForce);
+#endif
         combo = new QComboBox(this);
         combo->setObjectName(QStringLiteral("force_color_range_value"));
         combo->addItem(i18n("Broadcast limited (MPEG)"), 1);
@@ -1002,17 +1051,17 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
 
         // Check for variable frame rate
         if (m_properties->get_int("meta.media.variable_frame_rate")) {
-            m_warningMessage.setText(i18n("File uses a variable frame rate, not recommended"));
+            m_warningMessage->setText(i18n("File uses a variable frame rate, not recommended"));
             QAction *ac = new QAction(i18n("Transcode"));
             QObject::connect(ac, &QAction::triggered, [id = m_id, resource = controller->clipUrl()]() {
                 QMetaObject::invokeMethod(pCore->bin(), "requestTranscoding", Qt::QueuedConnection, Q_ARG(QString, resource), Q_ARG(QString, id), Q_ARG(int, 0),
                                           Q_ARG(bool, false));
             });
-            m_warningMessage.setMessageType(KMessageWidget::Warning);
-            m_warningMessage.addAction(ac);
-            m_warningMessage.show();
+            m_warningMessage->setMessageType(KMessageWidget::Warning);
+            m_warningMessage->addAction(ac);
+            m_warningMessage->show();
         } else {
-            m_warningMessage.hide();
+            m_warningMessage->hide();
         }
     }
     // Force properties page
@@ -1027,23 +1076,24 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
     forceAudioPage->setWidgetResizable(true);
 
     fpBox->addStretch(10);
+    const QSize iconSize = m_tabWidget->tabBar()->iconSize();
     m_tabWidget->addTab(m_propertiesPage, QString());
     m_tabWidget->addTab(forcePage, QString());
     m_tabWidget->addTab(forceAudioPage, QString());
     m_tabWidget->addTab(m_metaPage, QString());
     m_tabWidget->addTab(m_analysisPage, QString());
-    m_tabWidget->setTabIcon(0, QIcon::fromTheme(QStringLiteral("edit-find")));
+    m_tabWidget->setTabIcon(0, rotatedIcon(iconSize, QStringLiteral("edit-find")));
     m_tabWidget->setTabToolTip(0, i18n("File info"));
     m_tabWidget->setWhatsThis(xi18nc("@info:whatsthis", "Displays detailed information about the file."));
-    m_tabWidget->setTabIcon(1, QIcon::fromTheme(QStringLiteral("document-edit")));
+    m_tabWidget->setTabIcon(1, rotatedIcon(iconSize, QStringLiteral("document-edit")));
     m_tabWidget->setTabToolTip(1, i18n("Properties"));
     m_tabWidget->setWhatsThis(xi18nc("@info:whatsthis", "Displays detailed information about the video data/codec."));
-    m_tabWidget->setTabIcon(2, QIcon::fromTheme(QStringLiteral("audio-volume-high")));
+    m_tabWidget->setTabIcon(2, rotatedIcon(iconSize, QStringLiteral("audio-volume-high")));
     m_tabWidget->setTabToolTip(2, i18n("Audio Properties"));
     m_tabWidget->setWhatsThis(xi18nc("@info:whatsthis", "Displays detailed information about the audio streams/data/codec."));
     m_tabWidget->setTabIcon(3, QIcon::fromTheme(QStringLiteral("view-grid")));
     m_tabWidget->setTabToolTip(3, i18n("Metadata"));
-    m_tabWidget->setTabIcon(4, QIcon::fromTheme(QStringLiteral("visibility")));
+    m_tabWidget->setTabIcon(4, rotatedIcon(iconSize, QStringLiteral("visibility")));
     m_tabWidget->setTabToolTip(4, i18n("Analysis"));
     m_tabWidget->setWhatsThis(xi18nc("@info:whatsthis", "Displays analysis data."));
     m_tabWidget->setCurrentIndex(KdenliveSettings::properties_panel_page());
@@ -1053,6 +1103,16 @@ ClipPropertiesController::ClipPropertiesController(const QString &clipName, Clip
     connect(m_tabWidget, &QTabWidget::currentChanged, this, &ClipPropertiesController::updateTab);
 }
 
+QIcon ClipPropertiesController::rotatedIcon(const QSize iconSize, const QString &iconName)
+{
+    QIcon icon = QIcon::fromTheme(iconName);
+    QPixmap pix = icon.pixmap(iconSize);
+    QTransform trans;
+    trans.rotate(-90);
+    pix = pix.transformed(trans);
+    return QIcon(pix);
+}
+
 ClipPropertiesController::~ClipPropertiesController() = default;
 
 void ClipPropertiesController::updateStreamIcon(int row, int streamIndex)
@@ -1083,7 +1143,7 @@ void ClipPropertiesController::slotReloadProperties()
         m_originalProperties.insert(QStringLiteral("length"), m_properties->get("length"));
         Q_EMIT modified(m_properties->get_int("length"));
         color = m_properties->get_color("resource");
-        Q_EMIT modified(QColor::fromRgb(color.r, color.g, color.b));
+        Q_EMIT colorModified(QColor::fromRgb(color.r, color.g, color.b));
         break;
     case ClipType::TextTemplate:
         m_textEdit->setPlainText(m_properties->get("templatetext"));
@@ -1179,8 +1239,6 @@ void ClipPropertiesController::slotEnableForce(int state)
         if (param == QLatin1String("kdenlive:transparency")) {
             properties.insert(param, QString());
         } else if (param == QLatin1String("force_ar")) {
-            properties.insert(QStringLiteral("force_aspect_den"), QString());
-            properties.insert(QStringLiteral("force_aspect_num"), QString());
             properties.insert(QStringLiteral("force_aspect_ratio"), QString());
         } else if (param == QLatin1String("autorotate")) {
             properties.insert(QStringLiteral("autorotate"), QString());
@@ -1229,8 +1287,6 @@ void ClipPropertiesController::slotEnableForce(int state)
             if ((spin == nullptr) || (spin2 == nullptr)) {
                 return;
             }
-            properties.insert(QStringLiteral("force_aspect_den"), QString::number(spin2->value()));
-            properties.insert(QStringLiteral("force_aspect_num"), QString::number(spin->value()));
             properties.insert(QStringLiteral("force_aspect_ratio"), QString::number(double(spin->value()) / spin2->value(), 'f'));
         } else if (param == QLatin1String("disable_exif")) {
             properties.insert(QStringLiteral("disable_exif"), QString::number(1));
@@ -1277,8 +1333,6 @@ void ClipPropertiesController::slotAspectValueChanged(int)
         return;
     }
     QMap<QString, QString> properties;
-    properties.insert(QStringLiteral("force_aspect_den"), QString::number(spin2->value()));
-    properties.insert(QStringLiteral("force_aspect_num"), QString::number(spin->value()));
     properties.insert(QStringLiteral("force_aspect_ratio"), QString::number(double(spin->value()) / spin2->value(), 'f'));
     Q_EMIT updateClipProperties(m_id, m_originalProperties, properties);
     m_originalProperties = properties;
@@ -1354,8 +1408,8 @@ void ClipPropertiesController::fillProperties()
 
         if (vindex > -1) {
             // We have a video stream
-            QString codecInfo = QString("meta.media.%1.codec.").arg(vindex);
-            QString streamInfo = QString("meta.media.%1.stream.").arg(vindex);
+            const QString codecInfo = QStringLiteral("meta.media.%1.codec.").arg(vindex);
+            const QString streamInfo = QStringLiteral("meta.media.%1.stream.").arg(vindex);
             QString property = codecInfo + QStringLiteral("long_name");
             QString codec = m_sourceProperties->get(property.toUtf8().constData());
             if (!codec.isEmpty()) {
@@ -1408,7 +1462,7 @@ void ClipPropertiesController::fillProperties()
         if (default_audio > -1) {
             propertyMap.append({i18n("Audio streams:"), QString::number(m_controller->audioStreamsCount())});
 
-            QString codecInfo = QString("meta.media.%1.codec.").arg(default_audio);
+            QString codecInfo = QStringLiteral("meta.media.%1.codec.").arg(default_audio);
             QString property = codecInfo + QStringLiteral("long_name");
             QString codec = m_sourceProperties->get(property.toUtf8().constData());
             if (!codec.isEmpty()) {
@@ -1432,6 +1486,14 @@ void ClipPropertiesController::fillProperties()
         int tracks = m_sourceProperties->get_int("kdenlive:sequenceproperties.tracksCount");
         qDebug() << "============\nUPDATING TRACKS CNT: " << tracks << "\n============";
         propertyMap.append({i18n("Tracks:"), QString::number(tracks)});
+    } else if (m_type == ClipType::Playlist) {
+        // The sequence unique identifier
+        QMap<QString, QString> extra = m_controller->m_extraProperties;
+        QMapIterator<QString, QString> ix(extra);
+        while (ix.hasNext()) {
+            ix.next();
+            propertyMap.append({ix.key(), ix.value()});
+        }
     }
 
     qint64 filesize = m_sourceProperties->get_int64("kdenlive:file_size");
@@ -1481,7 +1543,7 @@ void ClipPropertiesController::slotFillMeta(QTreeWidget *tree)
                 m_controller->setProducerProperty(QStringLiteral("kdenlive:exiftool"), 1);
                 QTreeWidgetItem *exif = nullptr;
                 QStringList list = res.split(QLatin1Char('\n'));
-                for (const QString &tagline : qAsConst(list)) {
+                for (const QString &tagline : std::as_const(list)) {
                     if (tagline.startsWith(QLatin1String("-File")) || tagline.startsWith(QLatin1String("-ExifTool"))) {
                         continue;
                     }
@@ -1514,7 +1576,7 @@ void ClipPropertiesController::slotFillMeta(QTreeWidget *tree)
                     }
                     QTreeWidgetItem *exif = nullptr;
                     QStringList list = res.split(QLatin1Char('\n'));
-                    for (const QString &tagline : qAsConst(list)) {
+                    for (const QString &tagline : std::as_const(list)) {
                         if (m_type != ClipType::Image && !tagline.startsWith(QLatin1String("-H264"))) {
                             continue;
                         }
@@ -1677,7 +1739,7 @@ void ClipPropertiesController::updateStreamInfo(int streamIndex)
         m_copyChannel2->setChecked(effects.contains(QStringLiteral("channelcopy from=1 to=0")));
         m_normalize->setChecked(effects.contains(QStringLiteral("dynamic_loudness")));
         int gain = 0;
-        for (const QString &st : qAsConst(effects)) {
+        for (const QString &st : std::as_const(effects)) {
             if (st.startsWith(QLatin1String("volume "))) {
                 QSignalBlocker bk3(m_gain);
                 gain = st.section(QLatin1Char('='), 1).toInt();
