@@ -8,11 +8,7 @@
 #pragma once
 
 #include "definitions.h"
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include "videowidget.h"
-#else // Qt6
-#include "glwidget.h"
-#endif
 #include <QImage>
 #include <QObject>
 #include <QUrl>
@@ -25,7 +21,10 @@ class TimecodeDisplay;
  */
 class MonitorProxy : public QObject
 {
+    friend class AutomaskHelper;
+
     Q_OBJECT
+
     // Q_PROPERTY(int consumerPosition READ consumerPosition NOTIFY consumerPositionChanged)
     Q_PROPERTY(int position MEMBER m_position WRITE setPosition NOTIFY positionChanged)
     Q_PROPERTY(QPoint profile READ profile NOTIFY profileChanged)
@@ -42,7 +41,11 @@ class MonitorProxy : public QObject
     Q_PROPERTY(QList <int> audioChannels MEMBER m_audioChannels NOTIFY audioThumbChanged)
     Q_PROPERTY(int clipBounds MEMBER m_boundsCount NOTIFY clipBoundsChanged)
     Q_PROPERTY(int overlayType READ overlayType WRITE setOverlayType NOTIFY overlayTypeChanged)
+    Q_PROPERTY(int maskOpacity READ maskOpacity WRITE setMaskOpacity NOTIFY maskOpacityChanged)
+    Q_PROPERTY(bool maskInverted READ maskInverted WRITE setMaskInverted)
+    Q_PROPERTY(MaskModeType::MaskCreationMode maskMode MEMBER m_maskMode NOTIFY maskModeChanged)
     Q_PROPERTY(bool showGrid MEMBER m_showGrid NOTIFY showGridChanged)
+    Q_PROPERTY(bool builtinEffectsEnabled MEMBER m_builtinEffectsEnabled NOTIFY builtinEffectsEnabledChanged)
     Q_PROPERTY(int gridH READ gridH NOTIFY gridChanged)
     Q_PROPERTY(int gridV READ gridV NOTIFY gridChanged)
     Q_PROPERTY(double speed MEMBER m_speed NOTIFY speedChanged)
@@ -52,6 +55,7 @@ class MonitorProxy : public QObject
     Q_PROPERTY(bool autoKeyframe READ autoKeyframe NOTIFY autoKeyframeChanged)
     Q_PROPERTY(bool audioThumbFormat READ audioThumbFormat NOTIFY audioThumbFormatChanged)
     Q_PROPERTY(bool audioThumbNormalize READ audioThumbNormalize NOTIFY audioThumbNormalizeChanged)
+    Q_PROPERTY(bool permanentAudioThumb READ permanentAudioThumb NOTIFY permanentAudioThumbChanged)
     Q_PROPERTY(QStringList lastClips MEMBER m_lastClips NOTIFY lastClipsChanged)
     /** @brief Returns true if current clip in monitor has Audio and Video
      * */
@@ -59,6 +63,7 @@ class MonitorProxy : public QObject
     /** @brief Contains the name of clip currently displayed in monitor
      * */
     Q_PROPERTY(QString clipName MEMBER m_clipName NOTIFY clipNameChanged)
+    Q_PROPERTY(QUrl previewOverlay MEMBER m_previewOverlay NOTIFY previewOverlayChanged)
     Q_PROPERTY(QString clipStream MEMBER m_clipStream NOTIFY clipStreamChanged)
     /** @brief Contains the name of clip currently displayed in monitor
      * */
@@ -67,6 +72,7 @@ class MonitorProxy : public QObject
     Q_PROPERTY(QStringList runningJobs MEMBER m_runningJobs NOTIFY runningJobsChanged)
     Q_PROPERTY(QList<int> jobsProgress MEMBER m_jobsProgress NOTIFY jobsProgressChanged)
     Q_PROPERTY(QStringList jobsUuids MEMBER m_jobsUuids NOTIFY jobsProgressChanged)
+    Q_PROPERTY(bool monitorIsActive READ monitorIsActive NOTIFY activeMonitorChanged)
 
 public:
     MonitorProxy(VideoWidget *parent);
@@ -75,6 +81,12 @@ public:
     int rulerHeight() const;
     int overlayType() const;
     void setOverlayType(int ix);
+    int maskOpacity() const;
+    void setMaskOpacity(int opacity);
+    bool maskInverted() const;
+    void setMaskInverted(bool);
+    void setMaskMode(MaskModeType::MaskCreationMode ix);
+    MaskModeType::MaskCreationMode maskMode() const;
     const QString trimmingTC1() const;
     const QString trimmingTC2() const;
     const QString timecode() const;
@@ -93,6 +105,7 @@ public:
     Q_INVOKABLE const QPoint clipBoundary(int ix);
     bool audioThumbFormat() const;
     bool audioThumbNormalize() const;
+    bool permanentAudioThumb() const;
     void positionFromConsumer(int pos, bool playing);
     void setMarker(const QString &comment, const QColor &color);
     int zoneIn() const;
@@ -144,6 +157,8 @@ public:
     void setCursorPosition(int pos);
     void setJobsProgress(const ObjectId &owner, const QStringList &jobNames, const QList<int> &jobProgress, const QStringList &jobUuids);
     void clearJobsProgress();
+    void buildInEffectsChanged();
+    bool monitorIsActive() const;
 
 Q_SIGNALS:
     void positionChanged(int);
@@ -158,9 +173,12 @@ Q_SIGNALS:
     void removeSnap(int);
     void triggerAction(const QString &name);
     void overlayTypeChanged();
+    void maskOpacityChanged();
+    void maskModeChanged();
     void showGridChanged();
+    void builtinEffectsEnabledChanged();
     void gridChanged();
-    void addRemoveKeyframe();
+    void addRemoveKeyframe(bool addOnly = false);
     /** @brief Seek to an effect keyframe
      *  @param ix the index of the keyframe we want to reach
      *  @param offset if offset != 0, the ix param is ignored and we seek to previous (-1) or next(+1) keyframe
@@ -175,6 +193,7 @@ Q_SIGNALS:
     void colorsChanged();
     void audioThumbFormatChanged();
     void audioThumbNormalizeChanged();
+    void permanentAudioThumbChanged();
     void profileChanged();
     void autoKeyframeChanged();
     void timecodeChanged();
@@ -188,6 +207,11 @@ Q_SIGNALS:
     void lastClipsChanged();
     /** @brief Switch to another clip at the same time position that uses the same effect scene*/
     void switchFocusClip();
+    /** @brief Enable build-in transform effect*/
+    void enableTransform();
+    void previewOverlayChanged();
+    void refreshMask();
+    void activeMonitorChanged();
 
 private:
     VideoWidget *q;
@@ -201,6 +225,7 @@ private:
     QList <int> m_audioChannels;
     QString m_markerComment;
     QColor m_markerColor;
+    bool m_builtinEffectsEnabled{false};
     QString m_clipName;
     QString m_clipStream;
     int m_clipType;
@@ -217,6 +242,12 @@ private:
     QStringList m_jobsUuids;
     QVector<std::pair<int, QString>> m_lastClipsIds;
     QStringList m_lastClips;
+    bool m_switchFlag{false};
+
+protected:
+    QUrl m_previewOverlay;
+    /** @brief Mode for mask overlay. 0 = preview keyframe image, 1 = preview video mask*/
+    MaskModeType::MaskCreationMode m_maskMode{MaskModeType::MaskNone};
 
 public Q_SLOTS:
     void updateClipBounds(const QVector <QPoint>&bounds);
