@@ -49,16 +49,24 @@ ClipModel::ClipModel(const std::shared_ptr<TimelineModel> &parent, std::shared_p
     } else {
         m_endlessResize = false;
     }
-    QObject::connect(m_effectStack.get(), &EffectStackModel::dataChanged, [&](const QModelIndex &, const QModelIndex &, const QVector<int> &roles) {
-        qDebug() << "// GOT CLIP STACK DATA CHANGE: " << roles;
-        if (m_currentTrackId != -1) {
-            if (auto ptr = m_parent.lock()) {
-                QModelIndex ix = ptr->makeClipIndexFromID(m_id);
-                Q_EMIT ptr->dataChanged(ix, ix, roles);
-                qDebug() << "// GOT CLIP STACK DATA CHANGE DONE: " << ix << " = " << roles;
-            }
-        }
-    });
+    QObject::connect(m_effectStack.get(), &EffectStackModel::dataChanged, m_effectStack.get(),
+                     [&](const QModelIndex &, const QModelIndex &, const QVector<int> &roles) {
+                         if (m_currentTrackId != -1) {
+                             if (auto ptr = m_parent.lock()) {
+                                 QModelIndex ix = ptr->makeClipIndexFromID(m_id);
+                                 Q_EMIT ptr->dataChanged(ix, ix, roles);
+                             }
+                         }
+                     });
+    QObject::connect(m_effectStack.get(), &EffectStackModel::customDataChanged, m_effectStack.get(),
+                     [&](const QModelIndex &, const QModelIndex &, const QVector<int> &roles) {
+                         if (m_currentTrackId != -1) {
+                             if (auto ptr = m_parent.lock()) {
+                                 QModelIndex ix = ptr->makeClipIndexFromID(m_id);
+                                 Q_EMIT ptr->dataChanged(ix, ix, roles);
+                             }
+                         }
+                     });
 }
 
 int ClipModel::construct(const std::shared_ptr<TimelineModel> &parent, const QString &binClipId, int id, PlaylistState::ClipState state, int audioStream,
@@ -157,7 +165,8 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
     QWriteLocker locker(&m_lock);
     // qDebug() << "RESIZE CLIP" << m_id << "target size=" << size << "right=" << right << "endless=" << m_endlessResize << "length" <<
     // m_producer->get_length()<<" > "<<m_producer->get("kdenlive:duration")<<" = "<<m_producer->get("kdenlive:maxduration");
-    if (!m_endlessResize && (size <= 0 || size > m_producer->get_length()) && !hasTimeRemap()) {
+    int maxDuration = m_producer->get_length();
+    if (!m_endlessResize && (size <= 0 || size > maxDuration) && !hasTimeRemap()) {
         return false;
     }
     int delta = getPlaytime() - size;
@@ -174,7 +183,7 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
         if (!right && in + delta < 0) {
             return false;
         }
-        if (right && (out - delta >= m_producer->get_length()) && !hasTimeRemap()) {
+        if (right && (out - delta >= maxDuration) && !hasTimeRemap()) {
             return false;
         }
     }
@@ -197,7 +206,7 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
     }
     bool closing = false;
     // Ensure producer is long enough
-    if (m_endlessResize && outPoint > m_producer->parent().get_length()) {
+    if (m_endlessResize && outPoint > maxDuration) {
         m_producer->parent().set("length", outPoint + 1);
         m_producer->parent().set("out", outPoint);
         m_producer->set("length", outPoint + 1);
@@ -349,7 +358,7 @@ bool ClipModel::requestSlip(int offset, Fun &undo, Fun &redo, bool logUndo)
     Q_ASSERT(outPoint < m_producer->get_length());
     Q_ASSERT(inPoint >= 0);
     Q_ASSERT(inPoint <= m_producer->get_length() - m_producer->get_playtime());
-    Q_ASSERT(inPoint < outPoint);
+    Q_ASSERT(inPoint <= outPoint);
     Q_ASSERT(out - in == outPoint - inPoint);
 
     if (m_currentTrackId != -1) {
@@ -582,7 +591,7 @@ void ClipModel::requestRemapResize(int inPoint, int outPoint, int oldIn, int old
                     }
                 }
                 // Remove all requested keyframes
-                for (int d : qAsConst(toDelete)) {
+                for (int d : std::as_const(toDelete)) {
                     keyframes.remove(d);
                 }
                 // Add replacement keyframes
@@ -600,7 +609,7 @@ void ClipModel::requestRemapResize(int inPoint, int outPoint, int oldIn, int old
                         // HACK: we always set last keyframe 1 frame after in MLT to ensure we have a correct last frame
                         offset = 1;
                     }
-                    result << QString("%1=%2")
+                    result << QStringLiteral("%1=%2")
                                   .arg(m_producer->frames_to_time(j.key() + offset, mlt_time_clock))
                                   .arg(GenTime(j.value(), pCore->getCurrentFps()).seconds());
                 }
@@ -743,18 +752,18 @@ bool ClipModel::addEffect(const QString &effectId)
     return true;
 }
 
-bool ClipModel::addEffectWithUndo(const QString &effectId, Fun &undo, Fun &redo)
+std::pair<bool, bool> ClipModel::addEffectWithUndo(const QString &effectId, Fun &undo, Fun &redo)
 {
     QWriteLocker locker(&m_lock);
     if (EffectsRepository::get()->isAudioEffect(effectId)) {
         if (m_currentState == PlaylistState::VideoOnly) {
-            return false;
+            return {false, false};
         }
     } else if (m_currentState == PlaylistState::AudioOnly) {
-        return false;
+        return {false, false};
     }
     if (EffectsRepository::get()->isTextEffect(effectId) && m_clipType != ClipType::Text) {
-        return false;
+        return {false, false};
     }
     return m_effectStack->appendEffectWithUndo(effectId, undo, redo);
 }
@@ -1045,7 +1054,7 @@ bool ClipModel::useTimewarpProducer(double speed, bool pitchCompensate, bool cha
         };
     }
     if (revertSpeed) {
-        int out = getOut() + 1;
+        int out = getOut();
         int in = qMax(0, qRound((m_producer->get_length() - 1 - out) * std::fabs(m_speed / speed)));
         out = in + newDuration;
         operation = [operation, in, out, this]() {
@@ -1103,7 +1112,7 @@ std::shared_ptr<MarkerListModel> ClipModel::getMarkerModel() const
 int ClipModel::audioChannels() const
 {
     READ_LOCK();
-    return pCore->projectItemModel()->getClipByBinID(m_binClipId)->audioChannels();
+    return pCore->projectItemModel()->getClipByBinID(m_binClipId)->audioChannels(audioStream());
 }
 
 bool ClipModel::audioMultiStream() const
@@ -1433,6 +1442,19 @@ void ClipModel::setOffset(int offset)
     }
 }
 
+ItemInfo ClipModel::getItemInfo() const
+{
+    READ_LOCK();
+    ItemInfo info;
+    info.itemId = m_id;
+    info.position = m_position;
+    info.trackId = m_currentTrackId;
+    info.cropStart = m_producer->get_in();
+    info.playTime = m_producer->get_playtime();
+    info.maxDuration = m_endlessResize ? -1 : m_producer->get_length();
+    return info;
+}
+
 void ClipModel::setGrab(bool grab)
 {
     QWriteLocker locker(&m_lock);
@@ -1479,6 +1501,13 @@ int ClipModel::getMaxDuration() const
     if (m_endlessResize) {
         return -1;
     }
+    if (m_clipType == ClipType::Timeline) {
+        // Special case, timeline clips can in some cases be longer than max duration
+        int maxDuration = m_producer->parent().get_int("kdenlive:maxduration");
+        if (maxDuration > 0) {
+            return maxDuration;
+        }
+    }
     return m_producer->get_length();
 }
 
@@ -1552,9 +1581,9 @@ void ClipModel::switchBinReference(const QString newId, const QUuid &uuid)
     }
 }
 
-int ClipModel::assetRow(const QString &assetId, int eid) const
+int ClipModel::assetRow(const QString &assetId, int eid, bool enabledOnly) const
 {
-    return m_effectStack->effectRow(assetId, eid);
+    return m_effectStack->effectRow(assetId, eid, enabledOnly);
 }
 
 std::shared_ptr<KeyframeModelList> ClipModel::getKFModel(int row)
